#
# spec file for package perl-DBM-Deep
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name DBM-Deep
Name:           perl-DBM-Deep
Version:        2.0019
Release:        1.4
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Pure perl multi-level hash/array DBM that supports transactions
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DC/DCANTRELL/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Build) >= 0.42
BuildRequires:  perl(Test::Deep) >= 0.095
BuildRequires:  perl(Test::Exception) >= 0.21
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Warn) >= 0.08
%{perl_requires}

%description
A unique flat-file database module, written in pure perl. True multi-level
hash/array support (unlike MLDBM, which is faked), hybrid OO / tie()
interface, cross-platform FTPable files, ACID transactions, and is quite
fast. Can handle millions of keys and unlimited levels without significant
slow-down. Written from the ground-up in pure perl -- this is NOT a wrapper
around a C-based DBM. Out-of-the-box compatibility with Unix, Mac OS X and
Windows.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Mon Nov 13 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.0019
  see /usr/share/doc/packages/perl-DBM-Deep/Changes
  2.0019    2023-11-12
  - improvement so that when you try to put too much data in you get a
    useful error, and don't corrupt the db
  2.0018    2023-11-08
  - tiny documentation and metadata fixes to make sure people go to the
    correct issue tracker
* Tue Sep 26 2023 Tina Müller <tina.mueller@suse.com>
- Remove package-separator-perl5.38.patch, fixed upstream
* Tue Sep  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.0017
  see /usr/share/doc/packages/perl-DBM-Deep/Changes
  2.0017    2023-09-01
  - get rid of old perl4-style ' package separator and use :: instead
    for compatibility with perl 5.38
* Wed Aug  9 2023 Tina Müller <tina.mueller@suse.com>
- Add package-separator-perl5.38.patch, see
  https://rt.cpan.org/Public/Bug/Display.html?id=148417
* Tue May 22 2018 coolo@suse.com
- updated to 2.0016
  see /usr/share/doc/packages/perl-DBM-Deep/Changes
* Sat Jul 29 2017 coolo@suse.com
- updated to 2.0014
  see /usr/share/doc/packages/perl-DBM-Deep/Changes
  2.0014 Jul 27 22:15:00 2017 EDT
  - Fix for tests failing on 5.26 (Thanks, DrHyde!)
* Sat Jan  2 2016 coolo@suse.com
- updated to 2.0013
  see /usr/share/doc/packages/perl-DBM-Deep/Changes
  2.0013 Jan 01 20:30:00 2016 EDT
  - Updates to documentation by garu (Thanks!, GH#14, GH#15, GH#16)
* Mon Jun 22 2015 coolo@suse.com
- updated to 2.0012
  see /usr/share/doc/packages/perl-DBM-Deep/Changes
  2.0012 Jun 17 20:30:00 2015 PDT
  - Improved transaction validation and warnings (GH#12)
* Mon Mar 17 2014 coolo@suse.com
- fix spec file to build
* Sun Jan 26 2014 lars@linux-schulserver.de
- update to 2.0011
  + POD fixes by H. Merijn Brandt (The X<> tag - Thanks!)
* Sat Jan  4 2014 lars@linux-schulserver.de
- fix upstream URL
* Tue Nov 26 2013 coolo@suse.com
- updated to 2.0010
  - Can push undefined values onto arrays.
- remove unmaintained perl-DBM-Deep_Build_n_Test.patch
* Sat Jul 27 2013 coolo@suse.com
- updated to 2.0009, no changelog
* Tue Jun  4 2013 coolo@suse.com
- updated to 2.0008
  - Arrays and hashes retrieved from a database no longer create
    circular references (RT#77746).
  - Include one-line descriptions of each POD page after the name.
    Thanks to Yves Agostini for the patch and Gregor Herrmann for
    submitting it (RT#76378).
  - t/98_pod.t: Skip tests if Pod::Simple 3.21 is installed
    (RT#77419).
  - Er, try harder to get t/27_filehandle.t to work under TB2. The
    extra ‘TAP version 13’ line was causing a TAP parse error.
  - t/27_filehandle.t has been fixed again. It no longer violates
    Test::Builder’s encapsulation.
* Wed Feb 29 2012 ro@suse.de
- update Build_n_Test patch
* Fri Nov 18 2011 coolo@suse.com
- update to 2.0004, tons of changes - see Changes
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Jul 12 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- noarch pkg
- fixed deps
- added Build_n_Test patch
  o otherwise Test::More 0.88 would be needed
* Mon Jun  7 2010 lars@linux-schulserver.de
- update to 1.0025:
  + Fixed t/39_singletons.t to work on Windows
  + Stale references (objects blessed into DBM::Deep::Null), which
    have always supposed to act like undef, now compare equal to
    undef, "" and 0. $stale_ref eq "" used to return false, even
    though "$stale_ref" was the empty string.
  + If you assign a stale reference to a database location,
    DBM::Deep now warns and assigns undef, instead of dying with
    obscure error messages
  + Using a stale reference as a hash or array ref now causes an
    error with a more helpful message
* Mon May 10 2010 lars@linux-schulserver.de
- update to 1.0023:
  + The DBI back end no longer dies with ‘Use of uninitialized value
    $_ in lc’ in perl 5.12.0.
  + Singleton support has been re-enabled in the File back end
  + Correct spelling mistakes in the documentation
  + MANIFEST now lists the test libs so they get included in the
    distribution
* Mon Apr 12 2010 lars@linux-schulserver.de
- update to 1.0020:
  + Improved code coverage
  + Fixed speed regression with keys in the File backend
  + Had to turn off singleton support in the File backend because
    the caching was causing havoc with transactions. Turning on fatal
    warnings does give apparently important information.
  + Added support for DBD::SQLite
  ++ Build.PL has been extended to support sqlite vs. mysql
  ++ Storage::DBI now detects between the two DBDs
  + DBM::Deep has been refactored to allow for multiple engines.
    There are two engines built so far:
  ++ File (the original engine)
  ++ DBI (an engine based on DBI)
  + documentation updates/fixes
  + Fix deep recursion errors (RT#53575)
  + Avoid leaving temp files lying around (RT#32462)
  + Fixed bug with localized $ (RT #48031)
* Sat Dec 26 2009 lars@linux-schulserver.de
- initial version 1.0014
